@@ -61,6 +61,7 @@ class StrategyEvaluator(evaluator.AbstractEvaluator):
     async def strategy_completed(self,
                                  cryptocurrency: str = None,
                                  symbol: str = None,
+                                 time_frame=None,
                                  eval_note=None,
                                  eval_time=0,
                                  notify=True) -> None:
@@ -68,6 +69,7 @@ class StrategyEvaluator(evaluator.AbstractEvaluator):
         Main async method to notify that a strategy has updated its evaluation
         :param cryptocurrency: evaluated cryptocurrency
         :param symbol: evaluated symbol
+        :param time_frame: evaluated time frame
         :param eval_note: if None = self.eval_note
         :param eval_time: the time of the evaluation if relevant, default is 0
         :param notify: if true, will trigger matrix consumers
@@ -75,21 +77,21 @@ class StrategyEvaluator(evaluator.AbstractEvaluator):
         """
         return await self.evaluation_completed(cryptocurrency=cryptocurrency,
                                                symbol=symbol,
-                                               time_frame=None,
+                                               time_frame=time_frame,
                                                eval_note=eval_note,
                                                eval_time=eval_time,
                                                notify=notify,
                                                origin_consumer=self.consumer_instance)
 
-    def is_technical_evaluator_cycle_complete(self, matrix_id, evaluator_name, evaluator_type, exchange_name,
-                                              cryptocurrency, symbol, time_frame) -> bool:
+    def is_evaluator_cycle_complete(self, matrix_id, evaluator_name, evaluator_type, exchange_name,
+                                    cryptocurrency, symbol, time_frame) -> bool:
         """
-        :return: True if the strategy is to be waken up by technical evaluators at the moment of this call.
+        :return: True if the strategy is to be waken up by evaluators of the given type at the moment of this call.
         This avoids partial time frame updates wakeup.
         Override if necessary
         """
         # 1. Ensure this evaluation has not already been sent
-        # 2. Ensure every technical evaluator form this time frame are valid
+        # 2. Ensure every evaluator of the given type form this time frame are valid
         return not self._already_sent_this_technical_evaluation(matrix_id,
                                                                 evaluator_name,
                                                                 evaluator_type,
@@ -97,13 +99,13 @@ class StrategyEvaluator(evaluator.AbstractEvaluator):
                                                                 cryptocurrency,
                                                                 symbol,
                                                                 time_frame) and \
-               self._are_every_evaluation_valid(matrix_id,
-                                                evaluator_name,
-                                                evaluator_type,
-                                                exchange_name,
-                                                cryptocurrency,
-                                                symbol,
-                                                time_frame)
+               self._are_every_evaluation_valid_and_up_to_date(matrix_id,
+                                                               evaluator_name,
+                                                               evaluator_type,
+                                                               exchange_name,
+                                                               cryptocurrency,
+                                                               symbol,
+                                                               time_frame)
 
     def clear_cache(self):
         self.available_evaluators_cache = {}
@@ -115,6 +117,10 @@ class StrategyEvaluator(evaluator.AbstractEvaluator):
             await evaluator_channels.get_chan(constants.MATRIX_CHANNEL,
                                               self.matrix_id).remove_consumer(self.consumer_instance)
 
+    def get_full_cycle_evaluator_types(self) -> tuple:
+        # returns a tuple as it is faster to create than a list
+        return enums.EvaluatorMatrixTypes.TA.value,
+
     async def strategy_matrix_callback(self,
                                        matrix_id,
                                        evaluator_name,
@@ -126,18 +132,19 @@ class StrategyEvaluator(evaluator.AbstractEvaluator):
                                        symbol,
                                        time_frame):
         # if this callback is from a technical evaluator: ensure strategy should be notified at this moment
-        if evaluator_type == enums.EvaluatorMatrixTypes.TA.value:
-            # ensure this time frame is within the strategy's time frames
-            if common_enums.TimeFrames(time_frame) not in self.strategy_time_frames or \
-                    not self.is_technical_evaluator_cycle_complete(matrix_id,
-                                                                   evaluator_name,
-                                                                   evaluator_type,
-                                                                   exchange_name,
-                                                                   cryptocurrency,
-                                                                   symbol,
-                                                                   time_frame):
-                # do not call the strategy
-                return
+        for full_cycle_evaluator in self.get_full_cycle_evaluator_types():
+            if evaluator_type == full_cycle_evaluator:
+                # ensure this time frame is within the strategy's time frames
+                if common_enums.TimeFrames(time_frame) not in self.strategy_time_frames or \
+                        not self.is_evaluator_cycle_complete(matrix_id,
+                                                             evaluator_name,
+                                                             evaluator_type,
+                                                             exchange_name,
+                                                             cryptocurrency,
+                                                             symbol,
+                                                             time_frame):
+                    # do not call the strategy
+                    return
         await self.matrix_callback(
             matrix_id,
             evaluator_name,
@@ -164,15 +171,15 @@ class StrategyEvaluator(evaluator.AbstractEvaluator):
         # Do not forget to check if evaluator_name is self.name
         pass
 
-    def _are_every_evaluation_valid(self,
-                                    matrix_id,
-                                    evaluator_name,
-                                    evaluator_type,
-                                    exchange_name,
-                                    cryptocurrency,
-                                    symbol,
-                                    time_frame
-                                    ):
+    def _are_every_evaluation_valid_and_up_to_date(self,
+                                                   matrix_id,
+                                                   evaluator_name,
+                                                   evaluator_type,
+                                                   exchange_name,
+                                                   cryptocurrency,
+                                                   symbol,
+                                                   time_frame,
+                                                   can_retry=True):
         to_validate_node_paths = self._get_available_node_paths(matrix_id,
                                                                 evaluator_type,
                                                                 exchange_name,
@@ -181,14 +188,27 @@ class StrategyEvaluator(evaluator.AbstractEvaluator):
                                                                 use_cache=True)
         current_time = self._get_exchange_current_time(exchange_name, matrix_id)
         # ensure all evaluations are valid (do not trigger on an expired evaluation)
-        if all(matrix.is_tentacle_value_valid(self.matrix_id, evaluation_node_path,
-                                              timestamp=current_time,
-                                              delta=self.allowed_time_delta)
-               for evaluation_node_path in to_validate_node_paths):
-            self._save_last_evaluation(matrix_id, exchange_name, evaluator_type, evaluator_name,
-                                       cryptocurrency, symbol, time_frame)
-            return True
-        return False
+        try:
+            if all(matrix.is_tentacle_value_valid(self.matrix_id, evaluation_node_path,
+                                                  timestamp=current_time,
+                                                  delta=self.allowed_time_delta)
+                   for evaluation_node_path in to_validate_node_paths):
+                self._save_last_evaluation(matrix_id, exchange_name, evaluator_type, evaluator_name,
+                                           cryptocurrency, symbol, time_frame)
+                return True
+            return False
+        except KeyError:
+            self.clear_cache()
+            if can_retry:
+                return self._are_every_evaluation_valid_and_up_to_date(matrix_id,
+                                                                       evaluator_name,
+                                                                       evaluator_type,
+                                                                       exchange_name,
+                                                                       cryptocurrency,
+                                                                       symbol,
+                                                                       time_frame,
+                                                                       can_retry=False)
+            raise
 
     def _get_available_node_paths(self,
                                   matrix_id,
@@ -220,19 +240,21 @@ class StrategyEvaluator(evaluator.AbstractEvaluator):
 
     def _inner_get_available_node_paths(self, matrix_id, evaluator_type, exchange_name, cryptocurrency, symbol,
                                         use_cache=True):
-        return [
-            matrix.get_matrix_default_value_path(tentacle_name=evaluator,
-                                                 tentacle_type=evaluator_type,
-                                                 exchange_name=exchange_name,
-                                                 cryptocurrency=cryptocurrency,
-                                                 symbol=symbol,
-                                                 time_frame=time_frame)
-            for time_frame in self.get_available_time_frames(matrix_id, exchange_name, evaluator_type,
-                                                             cryptocurrency, symbol, use_cache=use_cache)
-            if common_enums.TimeFrames(time_frame) in self.strategy_time_frames
-            for evaluator in self._get_available_evaluators(matrix_id, exchange_name, evaluator_type,
-                                                            use_cache=use_cache)
-        ]
+        paths = []
+        for time_frame in self.get_available_time_frames(matrix_id, exchange_name, evaluator_type,
+                                                         cryptocurrency, symbol, use_cache=use_cache):
+            if common_enums.TimeFrames(time_frame) in self.strategy_time_frames:
+                for evaluator_name in self._get_available_evaluators(matrix_id, exchange_name, evaluator_type,
+                                                                     use_cache=use_cache):
+                    path = matrix.get_matrix_default_value_path(tentacle_name=evaluator_name,
+                                                                tentacle_type=evaluator_type,
+                                                                exchange_name=exchange_name,
+                                                                cryptocurrency=cryptocurrency,
+                                                                symbol=symbol,
+                                                                time_frame=time_frame)
+                    if matrix.get_tentacle_node(matrix_id, path) is not None:
+                        paths.append(path)
+        return paths
 
     def _save_last_evaluation(self, matrix_id, exchange_name, evaluator_type, tentacle_name,
                               cryptocurrency, symbol, time_frame):
