@@ -22,6 +22,7 @@ from octobot_evaluators.util.evaluation_util import (
     local_trading_context,
     local_cache_client,
     get_related_cache_identifiers,
+    get_required_candles_count,
 )
 
 __all__ = [
@@ -30,5 +31,6 @@ __all__ = [
     "local_trading_context",
     "local_cache_client",
     "get_related_cache_identifiers",
+    "get_required_candles_count",
 ]
 
